<div align="center">

# TorchRua

![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/speedcell4/torchrua/unit-tests.yml?cacheSeconds=0)
![PyPI - Version](https://img.shields.io/pypi/v/torchrua?label=pypi%20version&cacheSeconds=0)
![PyPI - Downloads](https://img.shields.io/pypi/dm/torchrua?cacheSeconds=0)

</div>

**Rua** derives from the [Szechwanese](https://en.wikipedia.org/wiki/Sichuanese_dialects) character <ruby>挼<rt>
ruá</rt></ruby> which means "pack, rumple, screw up, manipulate". TorchRua provides tons of easy-to-use functions to
help you rua tensors with `PackedSequence`, `CattedSequence`, and `PaddedSequence`!

## Installation

`python -m pip torchrua`